@@ -1,3 +1,5 @@
+import re
+from logging import getLogger
 from typing import Dict, Iterator, List
 
 from firebolt.common.exception import FireboltError
@@ -9,6 +11,8 @@ from prompt_toolkit.document import Document
 
 from firebolt_cli.keywords import FUNCTIONS, KEYWORDS
 
+logger = getLogger(__name__)
+
 
 def prepare_display_html(text: str, offset: int) -> HTML:
     """
@@ -24,10 +28,17 @@ def extract_last_word(text: str) -> str:
     """
     return the last word from the string
     """
-    delimiters = [" ", ",", "\n", ")", ";", "(", "."]
-    last_position = max([text.rfind(d) for d in delimiters])
+    words = re.split("\\ |,|\n|\\)|;|\\(|\\.", text)
+    return words[-1] if words else ""
 
-    return text[last_position + 1 :]
+
+def extract_last_complete_word(text: str) -> str:
+    """
+    extract last complete word (assuming that the last word could incomplete,
+    return the word before it)
+    """
+    words = re.split("\\ |\n|;", text)
+    return extract_last_word(words[-2]) if len(words) > 1 else ""
 
 
 class FireboltAutoCompleter(Completer):
@@ -44,8 +55,10 @@ class FireboltAutoCompleter(Completer):
         self.suggestions: List = []
         self.suggestions.extend((keyword, "KEYWORD") for keyword in KEYWORDS)
         self.suggestions.extend((function, "FUNCTION") for function in FUNCTIONS)
+        self.set_statements: List = []
 
         self.populate_table_and_column_names(cursor)
+        self.populate_set_statemets(cursor)
 
     def populate_table_and_column_names(self, cursor: Cursor) -> None:
         """
@@ -70,8 +83,30 @@ class FireboltAutoCompleter(Completer):
                 for table_name in self.table_columns_mapping.keys()
             )
 
-        except (FireboltError, HTTPStatusError):
-            pass
+        except (FireboltError, HTTPStatusError) as e:
+            logger.info(
+                f"Extraction of the list of table "
+                f"and columns names failed with: {str(e)}"
+            )
+
+    def populate_set_statemets(self, cursor: Cursor) -> None:
+        """
+        fetch all available set statements parameters
+        """
+        try:
+            cursor.execute("set use_standard_sql = 0")
+            cursor.execute("SELECT name FROM system.settings")
+            data = cursor.fetchall()
+
+            self.set_statements.extend(
+                (set_statement[0], "SET KEYWORD") for set_statement in data
+            )
+
+        except (FireboltError, HTTPStatusError) as e:
+            logger.info(
+                f"Extraction of the list of available "
+                f"set parameters failed with: {str(e)}"
+            )
 
     def get_completions(
         self, document: Document, complete_event: CompleteEvent
@@ -84,17 +119,20 @@ class FireboltAutoCompleter(Completer):
             - table and columns names
         """
         last_word = extract_last_word(document.text_before_cursor).upper()
-        if len(last_word) == 0:
-            return
+        last_full_word = extract_last_complete_word(document.text_before_cursor).upper()
 
-        current_suggestions: List = self.suggestions.copy()
+        current_suggestions: List = []
+        if last_full_word == "SET":
+            current_suggestions.extend(self.set_statements)
+        elif len(last_word) != 0:
+            current_suggestions.extend(self.suggestions)
 
-        for tb_name, columns in self.table_columns_mapping.items():
-            if tb_name in document.text:
-                current_suggestions.extend(
-                    (column_name, f"COLUMN ({column_type}, {tb_name})")
-                    for column_name, column_type in columns
-                )
+            for tb_name, columns in self.table_columns_mapping.items():
+                if tb_name in document.text:
+                    current_suggestions.extend(
+                        (column_name, f"COLUMN ({column_type}, {tb_name})")
+                        for column_name, column_type in columns
+                    )
 
         offset = len(last_word)
         for label, meta in current_suggestions:
