@@ -280,9 +280,10 @@ def engine_properties_options(create_mode: bool = True) -> Callable:
         option(
             "--auto-stop",
             help="Stop engine automatically after specified time in minutes."
-            "Value entered must be between 1 and 43200"
-            "(max value is equal to 30 days).",
-            type=IntRange(1, 30 * 24 * 60, clamp=False),
+            "Value entered must be between 0 and 43200"
+            "(max value is equal to 30 days). "
+            "Setting auto-stop to zero disables auto-stop.",
+            type=IntRange(0, 30 * 24 * 60, clamp=False),
             default=20 if create_mode else None,
             required=False,
             show_default=True,
@@ -586,6 +587,12 @@ def status(**raw_config_options: str) -> None:
     default=None,
     type=str,
 )
+@option(
+    "--database",
+    help="Only list engines attached to this database.",
+    default=None,
+    type=str,
+)
 @json_option
 @exit_on_firebolt_exception
 def list(**raw_config_options: str) -> None:
@@ -595,10 +602,27 @@ def list(**raw_config_options: str) -> None:
 
     rm = construct_resource_manager(**raw_config_options)
 
-    engines = rm.engines.get_many(
-        name_contains=raw_config_options["name_contains"],
-        order_by="ENGINE_ORDER_NAME_ASC",
-    )
+    if raw_config_options["database"]:
+        database = rm.databases.get_by_name(raw_config_options["database"])
+        engines = rm.bindings.get_engines_bound_to_database(database)
+
+        # Filter engines by name
+        if raw_config_options["name_contains"]:
+            name_contains = raw_config_options["name_contains"].lower()
+            engines = [
+                engine
+                for engine in engines
+                if engine.name
+                if name_contains in engine.name.lower()
+            ]
+
+        # Sort engines in alphabetical order
+        engines = sorted(engines, key=lambda x: x.name)
+    else:
+        engines = rm.engines.get_many(
+            name_contains=raw_config_options["name_contains"],
+            order_by="ENGINE_ORDER_NAME_ASC",
+        )
 
     if not raw_config_options["json"]:
         echo("Found {num_engines} engines".format(num_engines=len(engines)))
